==> ldp-0.11.0-py3-none-any.whl: ldp/graph/modules/thought.py <==
from collections.abc import Iterable, Mapping
from typing import Any

from aviary.message import Message
from aviary.tools import ToolRequestMessage

from ldp.graph.common_ops import FxnOp, PromptOp
from ldp.graph.modules import ParsedLLMCallModule
from ldp.graph.op_utils import compute_graph
from ldp.graph.ops import OpResult
from ldp.llms import prepend_sys_and_append_sys


class ThoughtModule:
    @staticmethod
    def _downcast_to_message(message: Message | ToolRequestMessage) -> Message:
        if isinstance(message, ToolRequestMessage):
            # Downcast into a normal Message if the LLM tried to call tools
            return Message(role=message.role, content=message.content)
        return message

    def __init__(
        self, llm_model: dict[str, Any], first_sys_prompt: str, second_sys_prompt: str
    ):
        self.first_sys_prompt_op = PromptOp(first_sys_prompt)
        self.second_sys_prompt_op = PromptOp(second_sys_prompt)
        self.package_msg_op = FxnOp(prepend_sys_and_append_sys)
        self.llm_call = ParsedLLMCallModule[Message](
            llm_model, parser=self._downcast_to_message
        )

    @compute_graph()
    async def __call__(
        self,
        messages: Iterable[Message],
        first_prompt_kwargs: Mapping[str, Any],
        second_prompt_kwargs: Mapping[str, Any],
    ) -> OpResult[Message]:
        packaged_msgs = await self.package_msg_op(
            messages,
            initial_sys_content=await self.first_sys_prompt_op(**first_prompt_kwargs),
            final_sys_content=await self.second_sys_prompt_op(**second_prompt_kwargs),
        )
        return (await self.llm_call(packaged_msgs))[0]  # type: ignore[arg-type]

==> ldp-0.11.1-py3-none-any.whl: ldp/graph/modules/thought.py <==
from collections.abc import Iterable, Mapping
from typing import Any

from aviary.message import Message
from aviary.tools import ToolRequestMessage

from ldp.graph import FxnOp, OpResult, PromptOp, compute_graph
from ldp.llms import prepend_sys_and_append_sys

from .llm_call import ParsedLLMCallModule


class ThoughtModule:
    @staticmethod
    def _downcast_to_message(message: Message | ToolRequestMessage) -> Message:
        if isinstance(message, ToolRequestMessage):
            # Downcast into a normal Message if the LLM tried to call tools
            return Message(role=message.role, content=message.content)
        return message

    def __init__(
        self, llm_model: dict[str, Any], first_sys_prompt: str, second_sys_prompt: str
    ):
        self.first_sys_prompt_op = PromptOp(first_sys_prompt)
        self.second_sys_prompt_op = PromptOp(second_sys_prompt)
        self.package_msg_op = FxnOp(prepend_sys_and_append_sys)
        self.llm_call = ParsedLLMCallModule[Message](
            llm_model, parser=self._downcast_to_message
        )

    @compute_graph()
    async def __call__(
        self,
        messages: Iterable[Message],
        first_prompt_kwargs: Mapping[str, Any],
        second_prompt_kwargs: Mapping[str, Any],
    ) -> OpResult[Message]:
        packaged_msgs = await self.package_msg_op(
            messages,
            initial_sys_content=await self.first_sys_prompt_op(**first_prompt_kwargs),
            final_sys_content=await self.second_sys_prompt_op(**second_prompt_kwargs),
        )
        return (await self.llm_call(packaged_msgs))[0]  # type: ignore[arg-type]
